clear all
close all

%%% Extract
% This program calculates the forces in a static determined pile system
% using Karl Culmann's approximated method (1821-1881).

%%% Short introduction to the theory
% The method uses the three equilibrium equations (vertical, horizontal and 
% moment equilibrium), hence there cannot be determined pile forces of more 
% than three piles. Therefore it is needed to define a maxi pile if there
% is more than three piles in the pile system. The maxi pile represents
% multiple piles, which must be parallel and located relatively close to
% each other.

% Sign convention
% Horizontal: Pos. to the right.
% Vertical: Pos. upwards.
% Moment: Pos. counter clockwise.
% Angle: Pos. clockwise.

% Author: Jon Andr Adsersen

%%%--- Inputs ----------------------------------------------------------%%%
n_safety=1.0; % Safety factor defined by the load acting on the pile 
% system divided by the load capacity of the pile system. 

V=-477*n_safety; % Vertical force acting on the pile system.
dist_V=3/2; % Point if attack for V (Horizontal distance measured from the 
% top of the pile located the longest to the left).

H=33*n_safety; % Point of attack for H.
dist_H=1; % Point of attack for H (Vertical distance measured form the top 
% of the piles).

% In the following two vectors the first column represents data for the pile 
% the longest to the left, the next the column represents the column to the
% right for the first pile and so on.

v=[0 0 -18.4]; % Angle with vertical [degrees].

dist=[0 1 2.5]; % Distance between the piles [m].

maxi=[1 2 3]; % Columns containing maxi piles.
n_maxi=[1 1 2]; % Number of piles in the respective maxi pile.

% The values of the two vectors above states, that all three piles are maxi
% piles, but when the two first maxi piles only consist of one pile
% each. This is equivalent to, that there is only one maxi pile being
% pile number 3.
%%%---------------------------------------------------------------------%%%

n=length(dist); % Number of piles.

% Name of the piles.
for i=1:n
    name_input=input(['Navn for pl ' num2str(i) ': '],'s');
    name(i)=cellstr(name_input); % The text string is converted to a cell string.
end

% Preallocation.
A=zeros(3,n);
b=zeros(3,1);

% A(1,:) - Horizontal equation.
% A(2,:) - Vertical equation.
% A(3,:) - Moment equation.

% The left side of the = for the three equations of equilibrium
A(1,:)=sind(v); % Horizontal equation of equilibrium.
A(2,:)=cosd(v); % Vertical equation of equilibrium.
A(3,:)=dist.*cosd(v); % Moment equation of equilibrium.

% The right side of the = for de three equations of equilibrium
b(1)=-H; % Horizontal equation of equilibrium.
b(2)=-V; % Vertical equation of equilibrium.
b(3)=-V*dist_V+H*dist_H; % Moment equation of equilibrium.

P=A\b; % The three pile forces is determined.

for i=1:length(maxi)
    P(maxi(i))=P(maxi(i))/n_maxi(i); % Each maxi pile is divided by the 
    % number of piles it contains.
end

% The forces of the piles are displayed.
disp('---')
disp(name)
disp(P')
%% Plot of the pile system
figure

y=[-2 0]; % Plotting height of the piles.

hold all

for i=1:n
    plot([dist(i)-tand(v(i))*2 dist(i)],y,'Linewidth',2) % Plot of the piles.
end
plot([min(dist)-0.5 max(dist)+0.5],[0 0],'Linewidth',2) % Plot of the concrete deck.


% The forces:
ref_l=abs(max(abs(V),abs(H))); % Max reference length for the forces.
max_l=1.5; % Max length for the forces.

% Plotting point of attack for H.
if dist_H==0
    H_x=0;
else
    H_x=0.5;
end

vectarrow([dist_V,H_x],[dist_V,H_x*1+V/ref_l*max_l],1) % Plot of V.
vectarrow([dist_V,H_x],[dist_V+H/ref_l*max_l,H_x],1) % Plot of H.


axis equal
axis([min(dist)-1 max(dist)+1 -2.5 2.5])

legend(name)